@@ -1,14 +1,15 @@
 ################################################################################
 #                            ForecasterAutoreg                                 #
 #                                                                              #
-# This work by Joaquin Amat Rodrigo is licensed under a Creative Commons       #
-# Attribution 4.0 International License.                                       #
+# This work by Joaquin Amat Rodrigo and Javier Escobar Ortiz is licensed       #
+# under a Creative Commons Attribution 4.0 International License.              #
 ################################################################################
 # coding=utf-8
 
 from typing import Union, Dict, List, Tuple, Any, Optional
 import warnings
 import logging
+import sys
 import numpy as np
 import pandas as pd
 import sklearn
@@ -25,6 +26,8 @@ from ..utils import preprocess_last_window
 from ..utils import preprocess_exog
 from ..utils import expand_index
 from ..utils import check_predict_input
+from ..utils import transform_series
+from ..utils import transform_dataframe
 
 logging.basicConfig(
     format = '%(name)-10s %(levelname)-5s %(message)s', 
@@ -33,7 +36,7 @@ logging.basicConfig(
 
 
 class ForecasterAutoreg(ForecasterBase):
-    '''
+    """
     This class turns any regressor compatible with the scikit-learn API into a
     recursive autoregressive (multi-step) forecaster.
     
@@ -48,6 +51,21 @@ class ForecasterAutoreg(ForecasterBase):
             `list`, `numpy ndarray` or `range`: include only lags present in `lags`,
             all elements must be int.
 
+    transformer_y : transformer (preprocessor) compatible with the scikit-learn
+                    preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API with methods: fit, transform, fit_transform and inverse_transform.
+        ColumnTransformers are not allowed since they do not have inverse_transform method.
+        The transformation is applied to `y` before training the forecaster. 
+        **New in version 0.5.0**
+
+    transformer_exog : transformer (preprocessor) compatible with the scikit-learn
+                       preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API. The transformation is applied to `exog` before training the
+        forecaster. `inverse_transform` is not available when using ColumnTransformers.
+        **New in version 0.5.0**
+
     
     Attributes
     ----------
@@ -56,6 +74,21 @@ class ForecasterAutoreg(ForecasterBase):
         
     lags : numpy ndarray
         Lags used as predictors.
+
+    transformer_y : transformer (preprocessor) compatible with the scikit-learn
+                    preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API with methods: fit, transform, fit_transform and inverse_transform.
+        ColumnTransformers are not allowed since they do not have inverse_transform method.
+        The transformation is applied to `y` before training the forecaster.
+        **New in version 0.5.0**
+
+    transformer_exog : transformer (preprocessor) compatible with the scikit-learn
+                    preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API. The transformation is applied to `exog` before training the
+        forecaster. `inverse_transform` is not available when using ColumnTransformers.
+        **New in version 0.5.0**
         
     max_lag : int
         Maximum value of lag included in `lags`.
@@ -64,11 +97,11 @@ class ForecasterAutoreg(ForecasterBase):
         Last window the forecaster has seen during trained. It stores the
         values needed to predict the next `step` right after the training data.
         
-    window_size: int
+    window_size : int
         Size of the window needed to create the predictors. It is equal to
         `max_lag`.
         
-    fitted: Bool
+    fitted : Bool
         Tag to identify if the regressor has been fitted (trained).
         
     index_type : type
@@ -77,7 +110,7 @@ class ForecasterAutoreg(ForecasterBase):
     index_freq : str
         Frequency of Index of the input used in training.
         
-    training_range: pandas Index
+    training_range : pandas Index
         First and last values of index of the data used during training.
         
     included_exog : bool
@@ -93,28 +126,40 @@ class ForecasterAutoreg(ForecasterBase):
     X_train_col_names : list
         Names of columns of the matrix created internally for training.
         
-    in_sample_residuals: numpy ndarray
+    in_sample_residuals : pandas Series
         Residuals of the model when predicting training data. Only stored up to
         1000 values.
         
-    out_sample_residuals: numpy ndarray
+    out_sample_residuals : pandas Series
         Residuals of the model when predicting non training data. Only stored
-        up to 1000 values.
+        up to 1000 values. Use `set_out_sample_residuals` to set values.
 
-    creation_date: str
+    creation_date : str
         Date of creation.
 
-    fit_date: str
+    fit_date : str
         Date of last fit.
 
     skforcast_version: str
         Version of skforecast library used to create the forecaster.
+
+    python_version : str
+        Version of python used to create the forecaster.
+        **New in version 0.5.0**
      
-    '''
+    """
     
-    def __init__(self, regressor, lags: Union[int, np.ndarray, list]) -> None:
+    def __init__(
+        self,
+        regressor,
+        lags: Union[int, np.ndarray, list],
+        transformer_y = None,
+        transformer_exog = None,
+    ) -> None:
         
         self.regressor            = regressor
+        self.transformer_y        = transformer_y
+        self.transformer_exog     = transformer_exog
         self.index_type           = None
         self.index_freq           = None
         self.training_range       = None
@@ -129,6 +174,7 @@ class ForecasterAutoreg(ForecasterBase):
         self.creation_date        = pd.Timestamp.today().strftime('%Y-%m-%d %H:%M:%S')
         self.fit_date             = None
         self.skforcast_version    = skforecast.__version__
+        self.python_version       = sys.version.split(" ")[0]
         
         if isinstance(lags, int) and lags < 1:
             raise Exception('Minimum value of lags allowed is 1.')
@@ -157,10 +203,12 @@ class ForecasterAutoreg(ForecasterBase):
         self.window_size = self.max_lag
 
 
-    def __repr__(self) -> str:
-        '''
+    def __repr__(
+        self
+    ) -> str:
+        """
         Information displayed when a ForecasterAutoreg object is printed.
-        '''
+        """
 
         if isinstance(self.regressor, sklearn.pipeline.Pipeline):
             name_pipe_steps = tuple(name + "__" for name in self.regressor.named_steps.keys())
@@ -175,6 +223,8 @@ class ForecasterAutoreg(ForecasterBase):
             f"{'=' * len(str(type(self)).split('.')[1])} \n"
             f"Regressor: {self.regressor} \n"
             f"Lags: {self.lags} \n"
+            f"Transformer for y: {self.transformer_y} \n"
+            f"Transformer for exog: {self.transformer_exog} \n"
             f"Window size: {self.window_size} \n"
             f"Included exogenous: {self.included_exog} \n"
             f"Type of exogenous variable: {self.exog_type} \n"
@@ -186,13 +236,17 @@ class ForecasterAutoreg(ForecasterBase):
             f"Creation date: {self.creation_date} \n"
             f"Last fit date: {self.fit_date} \n"
             f"Skforecast version: {self.skforcast_version} \n"
+            f"Python version: {self.python_version} \n"
         )
 
         return info
 
     
-    def _create_lags(self, y: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
-        '''       
+    def _create_lags(
+        self, 
+        y: np.ndarray
+    ) -> Tuple[np.ndarray, np.ndarray]:
+        """       
         Transforms a 1d array into a 2d array (X) and a 1d array (y). Each row
         in X is associated with a value of y and it represents the lags that
         precede it.
@@ -210,14 +264,20 @@ class ForecasterAutoreg(ForecasterBase):
         X_data : 2d numpy ndarray, shape (samples - max(self.lags), len(self.lags))
             2d numpy array with the lagged values (predictors).
         
-        y_data : 1d np.ndarray, shape (samples - max(self.lags),)
+        y_data : 1d numpy ndarray, shape (samples - max(self.lags),)
             Values of the time series related to each row of `X_data`.
-            
-        '''
+        
+        """
           
         n_splits = len(y) - self.max_lag
+        if n_splits <= 0:
+            raise ValueError(
+                f'The maximum lag ({self.max_lag}) must be less than the length '
+                f'of the series ({len(y)}).'
+            )
+        
         X_data   = np.full(shape=(n_splits, self.max_lag), fill_value=np.nan, dtype=float)
-        y_data   = np.full(shape=(n_splits, 1), fill_value=np.nan, dtype= float)
+        y_data   = np.full(shape=(n_splits, 1), fill_value=np.nan, dtype=float)
 
         for i in range(n_splits):
             X_index = np.arange(i, self.max_lag + i)
@@ -236,7 +296,7 @@ class ForecasterAutoreg(ForecasterBase):
         y: pd.Series,
         exog: Optional[Union[pd.Series, pd.DataFrame]]=None
     ) -> Tuple[pd.DataFrame, pd.Series]:
-        '''
+        """
         Create training matrices from univariate time series and exogenous
         variables.
         
@@ -257,22 +317,44 @@ class ForecasterAutoreg(ForecasterBase):
         y_train : pandas Series, shape (len(y) - self.max_lag, )
             Values (target) of the time series related to each row of `X_train`.
         
-        '''
+        """
         
         check_y(y=y)
+        y = transform_series(
+                series            = y,
+                transformer       = self.transformer_y,
+                fit               = True,
+                inverse_transform = False
+            )
         y_values, y_index = preprocess_y(y=y)
         
         if exog is not None:
             if len(exog) != len(y):
-                raise Exception(
-                    "`exog` must have same number of samples as `y`."
+                raise ValueError(
+                    f'`exog` must have same number of samples as `y`. '
+                    f'length `exog`: ({len(exog)}), length `y`: ({len(y)})'
                 )
             check_exog(exog=exog)
+            if isinstance(exog, pd.Series):
+                exog = transform_series(
+                            series            = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = True,
+                            inverse_transform = False
+                       )
+            else:
+                exog = transform_dataframe(
+                            df                = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = True,
+                            inverse_transform = False
+                       )
             exog_values, exog_index = preprocess_exog(exog=exog)
+            
             if not (exog_index[:len(y_index)] == y_index).all():
-                raise Exception(
-                ('Different index for `y` and `exog`. They must be equal '
-                'to ensure the correct alignment of values.')      
+                raise ValueError(
+                    ('Different index for `y` and `exog`. They must be equal '
+                     'to ensure the correct alignment of values.')      
                 )
         
         X_train, y_train = self._create_lags(y=y_values)
@@ -304,7 +386,7 @@ class ForecasterAutoreg(ForecasterBase):
         y: pd.Series,
         exog: Optional[Union[pd.Series, pd.DataFrame]]=None
     ) -> None:
-        '''
+        """
         Training Forecaster.
         
         Parameters
@@ -322,7 +404,7 @@ class ForecasterAutoreg(ForecasterBase):
         -------
         None
         
-        '''
+        """
         
         # Reset values in case the forecaster has already been fitted.
         self.index_type           = None
@@ -341,13 +423,14 @@ class ForecasterAutoreg(ForecasterBase):
             self.exog_type = type(exog)
             self.exog_col_names = \
                  exog.columns.to_list() if isinstance(exog, pd.DataFrame) else exog.name
- 
+
         X_train, y_train = self.create_train_X_y(y=y, exog=exog)
 
         if not str(type(self.regressor)) == "<class 'xgboost.sklearn.XGBRegressor'>":
             self.regressor.fit(X=X_train, y=y_train)
         else:
             self.regressor.fit(X=X_train.to_numpy(), y=y_train.to_numpy())
+        
         self.fitted = True
         self.fit_date = pd.Timestamp.today().strftime('%Y-%m-%d %H:%M:%S')
         self.training_range = preprocess_y(y=y)[1][[0, -1]]
@@ -361,24 +444,31 @@ class ForecasterAutoreg(ForecasterBase):
             residuals = y_train - self.regressor.predict(X_train)
         else:
             residuals = y_train - self.regressor.predict(X_train.to_numpy())
+
+        residuals = pd.Series(
+                        data  = residuals,
+                        index = y_train.index,
+                        name  = 'in_sample_residuals'
+                    )
+
         if len(residuals) > 1000:
             # Only up to 1000 residuals are stored
-            rng = np.random.default_rng(seed=123)
-            residuals = rng.choice(a=residuals, size=1000, replace=False)                                              
+            residuals = residuals.sample(n=1000, random_state=123, replace=False)
+                                                  
         self.in_sample_residuals = residuals
         
         # The last time window of training data is stored so that lags needed as
         # predictors in the first iteration of `predict()` can be calculated.
-        self.last_window = y_train.iloc[-self.max_lag:].copy()
+        self.last_window = y.iloc[-self.max_lag:].copy()
     
 
     def _recursive_predict(
         self,
         steps: int,
-        last_window: np.array,
-        exog: np.array
-    ) -> pd.Series:
-        '''
+        last_window: np.ndarray,
+        exog: np.ndarray
+    ) -> np.ndarray:
+        """
         Predict n steps ahead. It is an iterative process in which, each prediction,
         is used as a predictor for the next step.
         
@@ -398,8 +488,8 @@ class ForecasterAutoreg(ForecasterBase):
         -------
         predictions : numpy ndarray
             Predicted values.
-            
-        '''
+        
+        """
 
         predictions = np.full(shape=steps, fill_value=np.nan)
 
@@ -428,7 +518,7 @@ class ForecasterAutoreg(ForecasterBase):
         last_window: Optional[pd.Series]=None,
         exog: Optional[Union[pd.Series, pd.DataFrame]]=None
     ) -> pd.Series:
-        '''
+        """
         Predict n steps ahead. It is an recursive process in which, each prediction,
         is used as a predictor for the next step.
         
@@ -441,7 +531,7 @@ class ForecasterAutoreg(ForecasterBase):
             Values of the series used to create the predictors (lags) need in the 
             first iteration of prediction (t + 1).
     
-            If `last_window = None`, the values stored in` self.last_window` are
+            If `last_window = None`, the values stored in `self.last_window` are
             used to calculate the initial predictors, and the predictions start
             right after training data.
             
@@ -453,42 +543,60 @@ class ForecasterAutoreg(ForecasterBase):
         predictions : pandas Series
             Predicted values.
             
-        '''
+        """
 
         check_predict_input(
-            steps          = steps,
-            fitted         = self.fitted,
-            included_exog  = self.included_exog,
-            index_type     = self.index_type,
-            index_freq     = self.index_freq,
-            window_size    = self.window_size,
-            last_window    = last_window,
-            exog           = exog,
-            exog_type      = self.exog_type,
-            exog_col_names = self.exog_col_names,
-            max_steps      = None,
+            forecaster_type = type(self),
+            steps           = steps,
+            fitted          = self.fitted,
+            included_exog   = self.included_exog,
+            index_type      = self.index_type,
+            index_freq      = self.index_freq,
+            window_size     = self.window_size,
+            last_window     = last_window,
+            exog            = exog,
+            exog_type       = self.exog_type,
+            exog_col_names  = self.exog_col_names,
+            interval        = None,
+            max_steps       = None,
+            level           = None,
+            series_levels   = None
         ) 
 
         if exog is not None:
             if isinstance(exog, pd.DataFrame):
-                exog_values, _ = preprocess_exog(
-                                    exog = exog[self.exog_col_names].iloc[:steps, ]
-                                 )
-            else: 
-                exog_values, _ = preprocess_exog(
-                                    exog = exog.iloc[:steps, ]
-                                 )
+                exog = transform_dataframe(
+                            df                = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            else:
+                exog = transform_series(
+                            series            = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            
+            exog_values, _ = preprocess_exog(
+                                exog = exog.iloc[:steps, ]
+                             )
         else:
             exog_values = None
             
-        if last_window is not None:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = last_window
-                                                    )  
-        else:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = self.last_window
-                                                    )
+        if last_window is None:
+            last_window = self.last_window.copy()
+        
+        last_window = transform_series(
+                            series            = last_window,
+                            transformer       = self.transformer_y,
+                            fit               = False,
+                            inverse_transform = False
+                      )
+        last_window_values, last_window_index = preprocess_last_window(
+                                                    last_window = last_window
+                                                )
             
         predictions = self._recursive_predict(
                         steps       = steps,
@@ -505,6 +613,13 @@ class ForecasterAutoreg(ForecasterBase):
                         name = 'pred'
                       )
 
+        predictions = transform_series(
+                        series            = predictions,
+                        transformer       = self.transformer_y,
+                        fit               = False,
+                        inverse_transform = True
+                      )
+
         return predictions
     
     
@@ -518,7 +633,7 @@ class ForecasterAutoreg(ForecasterBase):
         random_state: int=123,
         in_sample_residuals: bool=True
     ) -> np.ndarray:
-        '''
+        """
         Iterative process in which, each prediction, is used as a predictor
         for the next step and bootstrapping is used to estimate prediction
         intervals. This method only returns prediction intervals.
@@ -540,19 +655,20 @@ class ForecasterAutoreg(ForecasterBase):
         exog : numpy ndarray, default `None`
             Exogenous variable/s included as predictor/s.
             
-        n_boot: int, default `500`
+        n_boot : int, default `500`
             Number of bootstrapping iterations used to estimate prediction
             intervals.
 
-        random_state: int
+        random_state : int
             Sets a seed to the random generator, so that boot intervals are always 
             deterministic.
             
-        interval: list, default `[5, 95]`
-            Confidence of the prediction interval estimated. Sequence of percentiles
-            to compute, which must be between 0 and 100 inclusive.
+        interval : list, default `[5, 95]`
+            Confidence of the prediction interval estimated. Sequence of 
+            percentiles to compute, which must be between 0 and 100 inclusive. 
+            For example, interval of 95% should be as `interval = [2.5, 97.5]`.
             
-        in_sample_residuals: bool, default `True`
+        in_sample_residuals : bool, default `True`
             If `True`, residuals from the training data are used as proxy of
             prediction error to create prediction intervals. If `False`, out of
             sample residuals are used. In the latter case, the user should have
@@ -564,8 +680,9 @@ class ForecasterAutoreg(ForecasterBase):
         -------
         prediction_interval : numpy ndarray, shape (steps, 2)
             Interval estimated for each prediction by bootstrapping:
-                first column = lower bound of the interval.
-                second column= upper bound interval of the interval.
+            
+            - lower_bound: lower bound of the interval.
+            - upper_bound: upper bound interval of the interval.
 
         Notes
         -----
@@ -574,7 +691,7 @@ class ForecasterAutoreg(ForecasterBase):
         Forecasting: Principles and Practice (2nd ed) Rob J Hyndman and
         George Athanasopoulos.
             
-        '''
+        """
         
         if last_window is None:
             last_window = self.last_window.values
@@ -613,7 +730,7 @@ class ForecasterAutoreg(ForecasterBase):
                                 steps       = 1,
                                 last_window = last_window_boot,
                                 exog        = exog_boot 
-                            )
+                             )
                 
                 prediction_with_residual  = prediction + sample_residuals[step]
                 boot_predictions[step, i] = prediction_with_residual
@@ -642,7 +759,7 @@ class ForecasterAutoreg(ForecasterBase):
         random_state: int=123,
         in_sample_residuals: bool=True
     ) -> pd.DataFrame:
-        '''
+        """
         Iterative process in which, each prediction, is used as a predictor
         for the next step and bootstrapping is used to estimate prediction
         intervals. Both, predictions and intervals, are returned.
@@ -663,19 +780,20 @@ class ForecasterAutoreg(ForecasterBase):
         exog : pandas Series, pandas DataFrame, default `None`
             Exogenous variable/s included as predictor/s.
             
-        interval: list, default `[5, 95]`
-            Confidence of the prediction interval estimated. Sequence of percentiles
-            to compute, which must be between 0 and 100 inclusive.
+        interval : list, default `[5, 95]`
+            Confidence of the prediction interval estimated. Sequence of 
+            percentiles to compute, which must be between 0 and 100 inclusive. 
+            For example, interval of 95% should be as `interval = [2.5, 97.5]`.
             
-        n_boot: int, default `500`
+        n_boot : int, default `500`
             Number of bootstrapping iterations used to estimate prediction
             intervals.
 
-        random_state: int, default 123
+        random_state : int, default 123
             Sets a seed to the random generator, so that boot intervals are always 
             deterministic.
             
-        in_sample_residuals: bool, default `True`
+        in_sample_residuals : bool, default `True`
             If `True`, residuals from the training data are used as proxy of
             prediction error to create prediction intervals. If `False`, out of
             sample residuals are used. In the latter case, the user should have
@@ -686,9 +804,10 @@ class ForecasterAutoreg(ForecasterBase):
         -------
         predictions : pandas DataFrame
             Values predicted by the forecaster and their estimated interval:
-                column pred = predictions.
-                column lower_bound = lower bound of the interval.
-                column upper_bound = upper bound interval of the interval.
+
+            - pred: predictions.
+            - lower_bound: lower bound of the interval.
+            - upper_bound: upper bound interval of the interval.
 
         Notes
         -----
@@ -697,43 +816,61 @@ class ForecasterAutoreg(ForecasterBase):
         Forecasting: Principles and Practice (2nd ed) Rob J Hyndman and
         George Athanasopoulos.
             
-        '''
+        """
         
         check_predict_input(
-            steps          = steps,
-            fitted         = self.fitted,
-            included_exog  = self.included_exog,
-            index_type     = self.index_type,
-            index_freq     = self.index_freq,
-            window_size    = self.window_size,
-            last_window    = last_window,
-            exog           = exog,
-            exog_type      = self.exog_type,
-            exog_col_names = self.exog_col_names,
-            max_steps      = None,
+            forecaster_type = type(self),
+            steps           = steps,
+            fitted          = self.fitted,
+            included_exog   = self.included_exog,
+            index_type      = self.index_type,
+            index_freq      = self.index_freq,
+            window_size     = self.window_size,
+            last_window     = last_window,
+            exog            = exog,
+            exog_type       = self.exog_type,
+            exog_col_names  = self.exog_col_names,
+            interval        = interval,
+            max_steps       = None,
+            level           = None,
+            series_levels   = None
         ) 
         
         if exog is not None:
             if isinstance(exog, pd.DataFrame):
-                exog_values, _ = preprocess_exog(
-                                    exog = exog[self.exog_col_names].iloc[:steps, ]
-                                 )
-            else: 
-                exog_values, _ = preprocess_exog(
-                                    exog = exog.iloc[:steps, ]
-                                 )
+                exog = transform_dataframe(
+                            df                = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            else:
+                exog = transform_series(
+                            series            = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            
+            exog_values, _ = preprocess_exog(
+                                exog = exog.iloc[:steps, ]
+                             )
         else:
             exog_values = None
-            
-        if last_window is not None:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = last_window
-                                                    )  
-        else:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = self.last_window
-                                                    )
         
+        if last_window is None:
+            last_window = self.last_window.copy()
+        
+        last_window = transform_series(
+                            series            = last_window,
+                            transformer       = self.transformer_y,
+                            fit               = False,
+                            inverse_transform = False
+                      )
+        last_window_values, last_window_index = preprocess_last_window(
+                                                    last_window = last_window
+                                                )
+
         # Since during predict() `last_window_values` and `exog_values` are modified,
         # the originals are stored to be used later.
         last_window_values_original = last_window_values.copy()
@@ -756,7 +893,7 @@ class ForecasterAutoreg(ForecasterBase):
                                     n_boot      = n_boot,
                                     random_state = random_state,
                                     in_sample_residuals = in_sample_residuals
-                                )
+                               )
         
         predictions = np.column_stack((predictions, predictions_interval))
 
@@ -768,12 +905,19 @@ class ForecasterAutoreg(ForecasterBase):
                                 ),
                         columns = ['pred', 'lower_bound', 'upper_bound']
                       )
+                      
+        if self.transformer_y:
+            for col in predictions.columns:
+                predictions[col] = self.transformer_y.inverse_transform(predictions[[col]])
 
         return predictions
 
     
-    def set_params(self, **params: dict) -> None:
-        '''
+    def set_params(
+        self, 
+        **params: dict
+    ) -> None:
+        """
         Set new values to the parameters of the scikit learn model stored in the
         ForecasterAutoreg.
         
@@ -786,13 +930,17 @@ class ForecasterAutoreg(ForecasterBase):
         -------
         self
         
-        '''
+        """
+
         self.regressor = clone(self.regressor)
         self.regressor.set_params(**params)
         
         
-    def set_lags(self, lags: Union[int, list, np.ndarray, range]) -> None:
-        '''      
+    def set_lags(
+        self, 
+        lags: Union[int, list, np.ndarray, range]
+    ) -> None:
+        """      
         Set new value to the attribute `lags`.
         Attributes `max_lag` and `window_size` are also updated.
         
@@ -807,7 +955,7 @@ class ForecasterAutoreg(ForecasterBase):
         -------
         None
         
-        '''
+        """
         
         if isinstance(lags, int) and lags < 1:
             raise Exception('min value of lags allowed is 1')
@@ -831,8 +979,13 @@ class ForecasterAutoreg(ForecasterBase):
         self.window_size = max(self.lags)
         
         
-    def set_out_sample_residuals(self, residuals: pd.Series, append: bool=True)-> None:
-        '''
+    def set_out_sample_residuals(
+        self, 
+        residuals: pd.Series, 
+        append: bool=True,
+        transform: bool=True
+    )-> None:
+        """
         Set new values to the attribute `out_sample_residuals`. Out of sample
         residuals are meant to be calculated using observations that did not
         participate in the training process.
@@ -848,22 +1001,51 @@ class ForecasterAutoreg(ForecasterBase):
             attribute `out_sample_residuals`. Once the limit of 1000 values is
             reached, no more values are appended. If False, `out_sample_residuals`
             is overwritten with the new residuals.
+
+        transform : bool, default `True`
+            If `True`, new residuals are transformed using self.transformer_y.
             
         Returns 
         -------
         self
-        '''
+
+        """
 
         if not isinstance(residuals, pd.Series):
             raise Exception(
                 f"`residuals` argument must be `pd.Series`. Got {type(residuals)}"
             )
 
+        if not transform and self.transformer_y is not None:
+            warnings.warn(
+                f'''
+                Argument `transform` is set to `False` but forecaster was trained
+                using a transformer {self.transformer_y}. Ensure that new residuals 
+                are already transformed or set `transform=True`.
+                '''
+            )
+
+        if transform and self.transformer_y is not None:
+            warnings.warn(
+                f'''
+                Residuals will be transformed using the same transformer used 
+                when training the forecaster ({self.transformer_y}). Ensure that
+                new residuals are in the same scale as the original time series.
+                '''
+            )
+
+            residuals = transform_series(
+                            series            = residuals,
+                            transformer       = self.transformer_y,
+                            fit               = False,
+                            inverse_transform = False
+                        )
+            
         if len(residuals) > 1000:
             rng = np.random.default_rng(seed=123)
             residuals = rng.choice(a=residuals, size=1000, replace=False)
             residuals = pd.Series(residuals)   
-      
+    
         if append and self.out_sample_residuals is not None:
             free_space = max(0, 1000 - len(self.out_sample_residuals))
             if len(residuals) < free_space:
@@ -879,52 +1061,11 @@ class ForecasterAutoreg(ForecasterBase):
 
         self.out_sample_residuals = pd.Series(residuals)
 
-
-    def get_coef(self) -> pd.DataFrame:
-        '''      
-        Return estimated coefficients for the regressor stored in the forecaster.
-        Only valid when regressor stores internally the feature coefficients in
-        the attribute `coef_`.
-        
-        Parameters
-        ----------
-        self
-
-        Returns 
-        -------
-        coef : pandas DataFrame
-            Value of the coefficients associated with each predictor.
-        
-        '''
-        warnings.warn(
-            f'This method was deprecated in version 0.4.3 in favor of the get_feature_importance. '
-            f'This method will be removed in 0.4.4', DeprecationWarning
-        )
-
-        if isinstance(self.regressor, sklearn.pipeline.Pipeline):
-            estimator = self.regressor[-1]
-        else:
-            estimator = self.regressor
-
-        try:
-            coef = pd.DataFrame({
-                        'feature': self.X_train_col_names,
-                        'coef' : estimator.coef_
-                   })
-        except:
-            warnings.warn(
-                f"Impossible to access feature coefficients for regressor of type {type(estimator)}. "
-                f"This method is only valid when the regressor stores internally "
-                f" the coefficients in the attribute `coef_`."
-            )
-
-            coef = None
-            
-        return coef
-
     
-    def get_feature_importance(self) -> pd.DataFrame:
-        '''      
+    def get_feature_importance(
+        self
+    ) -> pd.DataFrame:
+        """      
         Return feature importance of the regressor stored in the
         forecaster. Only valid when regressor stores internally the feature
         importance in the attribute `feature_importances_` or `coef_`.
@@ -937,7 +1078,14 @@ class ForecasterAutoreg(ForecasterBase):
         -------
         feature_importance : pandas DataFrame
             Feature importance associated with each predictor.
-        '''
+
+        """
+
+        if self.fitted == False:
+            raise sklearn.exceptions.NotFittedError(
+                "This forecaster is not fitted yet. Call `fit` with appropriate "
+                "arguments before using `get_feature_importance()`."
+            )
 
         if isinstance(self.regressor, sklearn.pipeline.Pipeline):
             estimator = self.regressor[-1]
@@ -965,4 +1113,4 @@ class ForecasterAutoreg(ForecasterBase):
 
                 feature_importance = None
 
-        return feature_importance
+        return feature_importance
\ No newline at end of file
