@@ -1,4 +1,4 @@
-# Unit test __init__
+# Unit test __init__ ForecasterAutoreg
 # ==============================================================================
 import pytest
 from pytest import approx
@@ -7,53 +7,60 @@ import pandas as pd
 from skforecast.ForecasterAutoreg import ForecasterAutoreg
 from sklearn.linear_model import LinearRegression
 
+
 def test_init_lags_when_integer():
-    '''
+    """
     Test creation of attribute lags when integer is passed.
-    '''
+    """
     forecaster = ForecasterAutoreg(LinearRegression(), lags=10)
     assert (forecaster.lags == np.arange(10) + 1).all()
     
+
 def test_init_lags_when_list():
-    '''
+    """
     Test creation of attribute lags when list is passed.
-    '''
+    """
     forecaster = ForecasterAutoreg(LinearRegression(), lags=[1, 2, 3])
     assert (forecaster.lags == np.array([1, 2, 3])).all()
-    
+
+
 def test_init_lags_when_range():
-    '''
+    """
     Test creation of attribute lags when range is passed.
-    '''
+    """
     forecaster = ForecasterAutoreg(LinearRegression(), lags=range(1, 4))
     assert (forecaster.lags == np.array(range(1, 4))).all()
-    
+
+
 def test_init_lags_when_numpy_arange():
-    '''
+    """
     Test creation of attribute lags when numpy arange is passed.
-    '''
+    """
     forecaster = ForecasterAutoreg(LinearRegression(), lags=np.arange(1, 10))
     assert (forecaster.lags == np.arange(1, 10)).all()
 
+
 def test_init_exception_when_lags_is_int_lower_than_1():
-    '''
+    """
     Test exception is raised when lags is initialized with int lower than 1.
-    '''
+    """
     with pytest.raises(Exception):
         ForecasterAutoreg(LinearRegression(), lags=-10)
-        
+
+
 def test_init_exception_when_lags_has_values_lower_than_1():
-    '''
+    """
     Test exception is raised when lags is initialized with any value lower than 1.
-    '''
+    """
     for lags in [[0, 1], range(0, 2), np.arange(0, 2)]:
         with pytest.raises(Exception):
             ForecasterAutoreg(LinearRegression(), lags=lags)
 
+
 def test_init_exception_when_lags_list_or_numpy_array_with_values_not_int():
-    '''
+    """
     Test exception is raised when lags is list or numpy array and element(s) are not int.
-    '''
+    """
     lags_list = [1, 1.5, [1, 2], range(5)]
     lags_np_array = np.array([1.2, 1.5])
     
@@ -61,4 +68,12 @@ def test_init_exception_when_lags_list_or_numpy_array_with_values_not_int():
         for lag in lags:
             if not isinstance(lag, (int, np.int64, np.int32)):
                 with pytest.raises(Exception):
-                    ForecasterAutoreg(LinearRegression(), lags=lags)
\ No newline at end of file
+                    ForecasterAutoreg(LinearRegression(), lags=lags)
+
+
+def test_init_exception_when_lags_is_not_valid_type():
+    """
+    Test exception is raised when lags is not a valid type.
+    """
+    with pytest.raises(Exception):
+        ForecasterAutoreg(LinearRegression(), lags='not_valid_type')
\ No newline at end of file
