@@ -1,14 +1,15 @@
 ################################################################################
 #                        ForecasterAutoregCustom                               #
 #                                                                              #
-# This work by Joaquin Amat Rodrigo is licensed under a Creative Commons       #
-# Attribution 4.0 International License.                                       #
+# This work by Joaquin Amat Rodrigo and Javier Escobar Ortiz is licensed       #
+# under a Creative Commons Attribution 4.0 International License.              #
 ################################################################################
 # coding=utf-8
 
 from typing import Union, Dict, List, Tuple, Any, Optional
 import warnings
 import logging
+import sys
 import numpy as np
 import pandas as pd
 import sklearn
@@ -26,7 +27,8 @@ from ..utils import preprocess_last_window
 from ..utils import preprocess_exog
 from ..utils import expand_index
 from ..utils import check_predict_input
-
+from ..utils import transform_series
+from ..utils import transform_dataframe
 
 logging.basicConfig(
     format = '%(name)-10s %(levelname)-5s %(message)s', 
@@ -44,37 +46,66 @@ class ForecasterAutoregCustom(ForecasterBase):
     regressor : regressor or pipeline compatible with the scikit-learn API
         An instance of a regressor or pipeline compatible with the scikit-learn API.
         
-    fun_predictors: Callable
+    fun_predictors : Callable
         Function that takes a numpy ndarray as a window of values as input and  
         returns a numpy ndarray with the predictors associated with that window.
         
-    window_size: int
+    window_size : int
         Size of the window needed by `fun_predictors` to create the predictors.
-    
+
+    transformer_y : transformer (preprocessor) compatible with the scikit-learn
+                    preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API with methods: fit, transform, fit_transform and inverse_transform.
+        ColumnTransformers are not allowed since they do not have inverse_transform method.
+        The transformation is applied to `y` before training the forecaster.
+        **New in version 0.5.0**
+
+    transformer_exog : transformer (preprocessor) compatible with the scikit-learn
+                       preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API. The transformation is applied to `exog` before training the
+        forecaster. `inverse_transform` is not available when using ColumnTransformers.
+        **New in version 0.5.0**
     
     Attributes
     ----------
     regressor : regressor compatible with the scikit-learn API
         An instance of a regressor compatible with the scikit-learn API.
         
-    create_predictors: Callable
+    create_predictors : Callable
         Function that takes a numpy ndarray as a window of values as input and  
         returns a numpy ndarray with the predictors associated with that window.
 
-    source_code_create_predictors: str
+    source_code_create_predictors : str
         Source code of the custom function used to create the predictors.
         
-    window_size: int
+    window_size : int
         Size of the window needed by `fun_predictors` to create the predictors.
-        
+
+    transformer_y : transformer (preprocessor) compatible with the scikit-learn
+                    preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API with methods: fit, transform, fit_transform and inverse_transform.
+        ColumnTransformers are not allowed since they do not have inverse_transform method.
+        The transformation is applied to `y` before training the forecaster.
+        **New in version 0.5.0**
+
+    transformer_exog : transformer (preprocessor) compatible with the scikit-learn
+                    preprocessing API, default `None`
+        An instance of a transformer (preprocessor) compatible with the scikit-learn
+        preprocessing API. The transformation is applied to `exog` before training the
+        forecaster. `inverse_transform` is not available when using ColumnTransformers.
+        **New in version 0.5.0**
+
     last_window : pandas Series
         Last window the forecaster has seen during trained. It stores the
         values needed to predict the next `step` right after the training data.
         
-    window_size: int
+    window_size : int
         Size of the window needed by `fun_predictors` to create the predictors.
         
-    fitted: Bool
+    fitted : Bool
         Tag to identify if the regressor has been fitted (trained).
         
     index_type : type
@@ -83,7 +114,7 @@ class ForecasterAutoregCustom(ForecasterBase):
     index_freq : str
         Frequency of Index of the input used in training.
         
-    training_range: pandas Index
+    training_range : pandas Index
         First and last values of index of the data used during training.
         
     included_exog : bool
@@ -99,44 +130,59 @@ class ForecasterAutoregCustom(ForecasterBase):
     X_train_col_names : list
         Names of columns of the matrix created internally for training.
         
-    in_sample_residuals: numpy ndarray
+    in_sample_residuals : pandas Series
         Residuals of the model when predicting training data. Only stored up to
         1000 values.
         
-    out_sample_residuals: numpy ndarray
+    out_sample_residuals : pandas Series
         Residuals of the model when predicting non training data. Only stored
-        up to 1000 values.
+        up to 1000 values. Use `set_out_sample_residuals` to set values.
 
-    creation_date: str
+    creation_date : str
         Date of creation.
 
-    fit_date: str
+    fit_date : str
         Date of last fit.
 
-    skforcast_version: str
+    skforcast_version : str
         Version of skforecast library used to create the forecaster.
+
+    python_version : str
+        Version of python used to create the forecaster.
+        **New in version 0.5.0**
      
     '''
     
-    def __init__(self, regressor, fun_predictors: callable, window_size: int) -> None:
+    def __init__(
+        self, 
+        regressor, 
+        fun_predictors: callable, 
+        window_size: int,
+        transformer_y = None,
+        transformer_exog = None,
+    ) -> None:
         
-        self.regressor            = regressor
-        self.create_predictors    = fun_predictors
-        self.window_size          = window_size
-        self.index_type           = None
-        self.index_freq           = None
-        self.training_range       = None
-        self.last_window          = None
-        self.included_exog        = False
-        self.exog_type            = None
-        self.exog_col_names       = None
-        self.X_train_col_names    = None
-        self.in_sample_residuals  = None
-        self.out_sample_residuals = None
-        self.fitted               = False
-        self.creation_date        = pd.Timestamp.today().strftime('%Y-%m-%d %H:%M:%S')
-        self.fit_date             = None
-        self.skforcast_version    = skforecast.__version__
+        self.regressor                     = regressor
+        self.create_predictors             = fun_predictors
+        self.source_code_create_predictors = None
+        self.window_size                   = window_size
+        self.transformer_y                 = transformer_y
+        self.transformer_exog              = transformer_exog
+        self.index_type                    = None
+        self.index_freq                    = None
+        self.training_range                = None
+        self.last_window                   = None
+        self.included_exog                 = False
+        self.exog_type                     = None
+        self.exog_col_names                = None
+        self.X_train_col_names             = None
+        self.in_sample_residuals           = None
+        self.out_sample_residuals          = None
+        self.fitted                        = False
+        self.creation_date                 = pd.Timestamp.today().strftime('%Y-%m-%d %H:%M:%S')
+        self.fit_date                      = None
+        self.skforcast_version             = skforecast.__version__
+        self.python_version                = sys.version.split(" ")[0]
         
         if not isinstance(window_size, int):
             raise Exception(
@@ -147,13 +193,16 @@ class ForecasterAutoregCustom(ForecasterBase):
             raise Exception(
                 f'`fun_predictors` must be callable, got {type(fun_predictors)}.'
             )
+    
         self.source_code_create_predictors = getsource(fun_predictors)
                 
         
-    def __repr__(self) -> str:
-        '''
+    def __repr__(
+        self
+    ) -> str:
+        """
         Information displayed when a ForecasterAutoregCustom object is printed.
-        '''
+        """
 
         if isinstance(self.regressor, sklearn.pipeline.Pipeline):
             name_pipe_steps = tuple(name + "__" for name in self.regressor.named_steps.keys())
@@ -169,6 +218,8 @@ class ForecasterAutoregCustom(ForecasterBase):
             f"Regressor: {self.regressor} \n"
             f"Predictors created with function: {self.create_predictors.__name__} \n"
             f"Window size: {self.window_size} \n"
+            f"Transformer for y: {self.transformer_y} \n"
+            f"Transformer for exog: {self.transformer_exog} \n"
             f"Included exogenous: {self.included_exog} \n"
             f"Type of exogenous variable: {self.exog_type} \n"
             f"Exogenous variables names: {self.exog_col_names} \n"
@@ -179,6 +230,7 @@ class ForecasterAutoregCustom(ForecasterBase):
             f"Creation date: {self.creation_date} \n"
             f"Last fit date: {self.fit_date} \n"
             f"Skforecast version: {self.skforcast_version} \n"
+            f"Python version: {self.python_version} \n"
         )
 
         return info
@@ -189,7 +241,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         y: pd.Series,
         exog: Optional[Union[pd.Series, pd.DataFrame]]=None
     ) -> Tuple[pd.DataFrame, pd.Series]:
-        '''
+        """
         Create training matrices from univariate time series.
         
         Parameters
@@ -210,7 +262,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         y_train : pandas Series
             Values (target) of the time series related to each row of `X_train`.
         
-        '''
+        """
         
         if len(y) < self.window_size + 1:
             raise Exception(
@@ -220,6 +272,12 @@ class ForecasterAutoregCustom(ForecasterBase):
             )
 
         check_y(y=y)
+        y = transform_series(
+                series            = y,
+                transformer       = self.transformer_y,
+                fit               = True,
+                inverse_transform = False
+            )
         y_values, y_index = preprocess_y(y=y)
         
         if exog is not None:
@@ -228,11 +286,25 @@ class ForecasterAutoregCustom(ForecasterBase):
                     "`exog` must have same number of samples as `y`."
                 )
             check_exog(exog=exog)
+            if isinstance(exog, pd.Series):
+                exog = transform_series(
+                            series            = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = True,
+                            inverse_transform = False
+                       )
+            else:
+                exog = transform_dataframe(
+                            df                = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = True,
+                            inverse_transform = False
+                       )
             exog_values, exog_index = preprocess_exog(exog=exog)
             if not (exog_index[:len(y_index)] == y_index).all():
                 raise Exception(
-                ('Different index for `y` and `exog`. They must be equal '
-                'to ensure the correct alignment of values.')      
+                    ('Different index for `y` and `exog`. They must be equal '
+                     'to ensure the correct alignment of values.')      
                 )
        
         X_train  = []
@@ -279,10 +351,10 @@ class ForecasterAutoregCustom(ForecasterBase):
         
     def fit(
         self,
-        y: Union[np.ndarray, pd.Series],
+        y: pd.Series,
         exog: Optional[Union[np.ndarray, pd.Series, pd.DataFrame]]=None
     ) -> None:
-        '''
+        """
         Training Forecaster.
         
         Parameters
@@ -300,7 +372,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         -------
         None
         
-        '''
+        """
         
         # Reset values in case the forecaster has already been fitted.
         self.index_type           = None
@@ -326,6 +398,7 @@ class ForecasterAutoregCustom(ForecasterBase):
             self.regressor.fit(X=X_train, y=y_train)
         else:
             self.regressor.fit(X=X_train.to_numpy(), y=y_train.to_numpy())
+        
         self.fitted = True
         self.fit_date = pd.Timestamp.today().strftime('%Y-%m-%d %H:%M:%S')
         self.training_range = preprocess_y(y=y)[1][[0, -1]]
@@ -339,24 +412,31 @@ class ForecasterAutoregCustom(ForecasterBase):
             residuals = y_train - self.regressor.predict(X_train)
         else:
             residuals = y_train - self.regressor.predict(X_train.to_numpy())
+            
+        residuals = pd.Series(
+                        data  = residuals,
+                        index = y_train.index,
+                        name  = 'in_sample_residuals'
+                    )
+
         if len(residuals) > 1000:
             # Only up to 1000 residuals are stored
-            rng = np.random.default_rng(seed=123)
-            residuals = rng.choice(a=residuals, size=1000, replace=False)                                              
+            residuals = residuals.sample(n=1000, random_state=123, replace=False)
+                                                  
         self.in_sample_residuals = residuals
         
         # The last time window of training data is stored so that predictors in
         # the first iteration of `predict()` can be calculated.
-        self.last_window = y_train.iloc[-self.window_size:].copy()
+        self.last_window = y.iloc[-self.window_size:].copy()
 
 
     def _recursive_predict(
         self,
         steps: int,
-        last_window: np.array,
-        exog: np.array
-    ) -> pd.Series:
-        '''
+        last_window: np.ndarray,
+        exog: np.ndarray
+    ) -> np.array:
+        """
         Predict n steps ahead. It is an iterative process in which, each prediction,
         is used as a predictor for the next step.
         
@@ -377,7 +457,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         predictions : numpy ndarray
             Predicted values.
             
-        '''
+        """
 
         predictions = np.full(shape=steps, fill_value=np.nan)
 
@@ -410,7 +490,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         last_window: Optional[pd.Series]=None,
         exog: Optional[Union[pd.Series, pd.DataFrame]]=None
     ) -> pd.Series:
-        '''
+        """
         Predict n steps ahead. It is an recursive process in which, each prediction,
         is used as a predictor for the next step.
         
@@ -435,42 +515,60 @@ class ForecasterAutoregCustom(ForecasterBase):
         predictions : pandas Series
             Predicted values.
             
-        '''
+        """
 
         check_predict_input(
-            steps          = steps,
-            fitted         = self.fitted,
-            included_exog  = self.included_exog,
-            index_type     = self.index_type,
-            index_freq     = self.index_freq,
-            window_size    = self.window_size,
-            last_window    = last_window,
-            exog           = exog,
-            exog_type      = self.exog_type,
-            exog_col_names = self.exog_col_names,
-            max_steps      = None,
+            forecaster_type = type(self),
+            steps           = steps,
+            fitted          = self.fitted,
+            included_exog   = self.included_exog,
+            index_type      = self.index_type,
+            index_freq      = self.index_freq,
+            window_size     = self.window_size,
+            last_window     = last_window,
+            exog            = exog,
+            exog_type       = self.exog_type,
+            exog_col_names  = self.exog_col_names,
+            interval        = None,
+            max_steps       = None,
+            level           = None,
+            series_levels   = None
         )
      
         if exog is not None:
             if isinstance(exog, pd.DataFrame):
-                exog_values, _ = preprocess_exog(
-                                    exog = exog[self.exog_col_names].iloc[:steps, ]
-                                 )
-            else: 
-                exog_values, _ = preprocess_exog(
-                                    exog = exog.iloc[:steps, ]
-                                 )
+                exog = transform_dataframe(
+                            df                = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            else:
+                exog = transform_series(
+                            series            = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            
+            exog_values, _ = preprocess_exog(
+                                exog = exog.iloc[:steps, ]
+                             )
         else:
             exog_values = None
         
-        if last_window is not None:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = last_window
-                                                    )  
-        else:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = self.last_window
-                                                    )
+        if last_window is None:
+            last_window = self.last_window.copy()
+        
+        last_window = transform_series(
+                            series            = last_window,
+                            transformer       = self.transformer_y,
+                            fit               = False,
+                            inverse_transform = False
+                      )
+        last_window_values, last_window_index = preprocess_last_window(
+                                                    last_window = last_window
+                                                )
             
         predictions = self._recursive_predict(
                         steps       = steps,
@@ -487,6 +585,13 @@ class ForecasterAutoregCustom(ForecasterBase):
                         name = 'pred'
                       )
 
+        predictions = transform_series(
+                        series            = predictions,
+                        transformer       = self.transformer_y,
+                        fit               = False,
+                        inverse_transform = True
+                      )
+
         return predictions
 
     
@@ -501,7 +606,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         random_state: int=123,
         in_sample_residuals: bool=True
     ) -> np.ndarray:
-        '''
+        """
         Iterative process in which, each prediction, is used as a predictor
         for the next step and bootstrapping is used to estimate prediction
         intervals. This method only returns prediction intervals.
@@ -523,19 +628,20 @@ class ForecasterAutoregCustom(ForecasterBase):
         exog : numpy ndarray, default `None`
             Exogenous variable/s included as predictor/s.
             
-        n_boot: int, default `500`
+        n_boot : int, default `500`
             Number of bootstrapping iterations used to estimate prediction
             intervals.
 
-        random_state: int
+        random_state : int
             Sets a seed to the random generator, so that boot intervals are always 
             deterministic.
             
-        interval: list, default `[5, 95]`
-            Confidence of the prediction interval estimated. Sequence of percentiles
-            to compute, which must be between 0 and 100 inclusive.
+        interval : list, default `[5, 95]`
+            Confidence of the prediction interval estimated. Sequence of 
+            percentiles to compute, which must be between 0 and 100 inclusive. 
+            For example, interval of 95% should be as `interval = [2.5, 97.5]`.
             
-        in_sample_residuals: bool, default `True`
+        in_sample_residuals : bool, default `True`
             If `True`, residuals from the training data are used as proxy of
             prediction error to create prediction intervals. If `False`, out of
             sample residuals are used. In the latter case, the user should have
@@ -547,8 +653,9 @@ class ForecasterAutoregCustom(ForecasterBase):
         -------
         prediction_interval : numpy ndarray, shape (steps, 2)
             Interval estimated for each prediction by bootstrapping:
-                first column = lower bound of the interval.
-                second column= upper bound interval of the interval.
+                
+            - lower_bound: lower bound of the interval.
+            - upper_bound: upper bound interval of the interval.
 
         Notes
         -----
@@ -557,7 +664,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         Forecasting: Principles and Practice (2nd ed) Rob J Hyndman and
         George Athanasopoulos.
             
-        '''
+        """
 
         if last_window is None:
             last_window = self.last_window.values
@@ -597,7 +704,7 @@ class ForecasterAutoregCustom(ForecasterBase):
                                 steps       = 1,
                                 last_window = last_window_boot,
                                 exog        = exog_boot 
-                            )
+                             )
                 
                 prediction_with_residual  = prediction + sample_residuals[step]
                 boot_predictions[step, i] = prediction_with_residual
@@ -626,7 +733,7 @@ class ForecasterAutoregCustom(ForecasterBase):
         random_state: int=123,
         in_sample_residuals: bool=True
     ) -> pd.DataFrame:
-        '''
+        """
         Iterative process in which, each prediction, is used as a predictor
         for the next step and bootstrapping is used to estimate prediction
         intervals. Both, predictions and intervals, are returned.
@@ -647,19 +754,20 @@ class ForecasterAutoregCustom(ForecasterBase):
         exog : pandas Series, pandas DataFrame, default `None`
             Exogenous variable/s included as predictor/s.
             
-        interval: list, default `[5, 95]`
-            Confidence of the prediction interval estimated. Sequence of percentiles
-            to compute, which must be between 0 and 100 inclusive.
+        interval : list, default `[5, 95]`
+            Confidence of the prediction interval estimated. Sequence of 
+            percentiles to compute, which must be between 0 and 100 inclusive. 
+            For example, interval of 95% should be as `interval = [2.5, 97.5]`.
             
-        n_boot: int, default `500`
+        n_boot : int, default `500`
             Number of bootstrapping iterations used to estimate prediction
             intervals.
 
-        random_state: int, default 123
+        random_state : int, default 123
             Sets a seed to the random generator, so that boot intervals are always 
             deterministic.
             
-        in_sample_residuals: bool, default `True`
+        in_sample_residuals : bool, default `True`
             If `True`, residuals from the training data are used as proxy of
             prediction error to create prediction intervals. If `False`, out of
             sample residuals are used. In the latter case, the user should have
@@ -670,9 +778,10 @@ class ForecasterAutoregCustom(ForecasterBase):
         -------
         predictions : pandas DataFrame
             Values predicted by the forecaster and their estimated interval:
-                column pred = predictions.
-                column lower_bound = lower bound of the interval.
-                column upper_bound = upper bound interval of the interval.
+
+            - pred: predictions.
+            - lower_bound: lower bound of the interval.
+            - upper_bound: upper bound interval of the interval.
 
         Notes
         -----
@@ -681,42 +790,60 @@ class ForecasterAutoregCustom(ForecasterBase):
         Forecasting: Principles and Practice (2nd ed) Rob J Hyndman and
         George Athanasopoulos.
             
-        '''
+        """
         
         check_predict_input(
-            steps          = steps,
-            fitted         = self.fitted,
-            included_exog  = self.included_exog,
-            index_type     = self.index_type,
-            index_freq     = self.index_freq,
-            window_size    = self.window_size,
-            last_window    = last_window,
-            exog           = exog,
-            exog_type      = self.exog_type,
-            exog_col_names = self.exog_col_names,
-            max_steps      = None,
+            forecaster_type = type(self),
+            steps           = steps,
+            fitted          = self.fitted,
+            included_exog   = self.included_exog,
+            index_type      = self.index_type,
+            index_freq      = self.index_freq,
+            window_size     = self.window_size,
+            last_window     = last_window,
+            exog            = exog,
+            exog_type       = self.exog_type,
+            exog_col_names  = self.exog_col_names,
+            interval        = interval,
+            max_steps       = None,
+            level           = None,
+            series_levels   = None
         )
         
         if exog is not None:
             if isinstance(exog, pd.DataFrame):
-                exog_values, _ = preprocess_exog(
-                                    exog = exog[self.exog_col_names].iloc[:steps, ]
-                                 )
-            else: 
-                exog_values, _ = preprocess_exog(
-                                    exog = exog.iloc[:steps, ]
-                                 )
+                exog = transform_dataframe(
+                            df                = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            else:
+                exog = transform_series(
+                            series            = exog,
+                            transformer       = self.transformer_exog,
+                            fit               = False,
+                            inverse_transform = False
+                       )
+            
+            exog_values, _ = preprocess_exog(
+                                exog = exog.iloc[:steps, ]
+                             )
         else:
             exog_values = None
             
-        if last_window is not None:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = last_window
-                                                    )  
-        else:
-            last_window_values, last_window_index = preprocess_last_window(
-                                                        last_window = self.last_window
-                                                    )
+        if last_window is None:
+            last_window = self.last_window.copy()
+        
+        last_window = transform_series(
+                            series            = last_window,
+                            transformer       = self.transformer_y,
+                            fit               = False,
+                            inverse_transform = False
+                      )
+        last_window_values, last_window_index = preprocess_last_window(
+                                                    last_window = last_window
+                                                )
         
         # Since during predict() `last_window` and `exog` are modified, the
         # originals are stored to be used later
@@ -740,7 +867,7 @@ class ForecasterAutoregCustom(ForecasterBase):
                                     n_boot      = n_boot,
                                     random_state = random_state,
                                     in_sample_residuals = in_sample_residuals
-                                )
+                               )
         
         predictions = np.column_stack((predictions, predictions_interval))
 
@@ -752,12 +879,19 @@ class ForecasterAutoregCustom(ForecasterBase):
                                 ),
                         columns = ['pred', 'lower_bound', 'upper_bound']
                       )
+                      
+        if self.transformer_y:
+            for col in predictions.columns:
+                predictions[col] = self.transformer_y.inverse_transform(predictions[[col]])
 
         return predictions
 
     
-    def set_params(self, **params: dict) -> None:
-        '''
+    def set_params(
+        self, 
+        **params: dict
+    ) -> None:
+        """
         Set new values to the parameters of the scikit learn model stored in the
         ForecasterAutoregCustom.
         
@@ -770,14 +904,19 @@ class ForecasterAutoregCustom(ForecasterBase):
         -------
         self
         
-        '''
+        """
         
         self.regressor = clone(self.regressor)
         self.regressor.set_params(**params)
         
     
-    def set_out_sample_residuals(self, residuals: pd.Series, append: bool=True)-> None:
-        '''
+    def set_out_sample_residuals(
+        self, 
+        residuals: pd.Series, 
+        append: bool=True,
+        transform: bool=True
+    )-> None:
+        """
         Set new values to the attribute `out_sample_residuals`. Out of sample
         residuals are meant to be calculated using observations that did not
         participate in the training process.
@@ -793,16 +932,45 @@ class ForecasterAutoregCustom(ForecasterBase):
             attribute `out_sample_residuals`. Once the limit of 1000 values is
             reached, no more values are appended. If False, `out_sample_residuals`
             is overwritten with the new residuals.
+
+        transform : bool, default `True`
+            If `True`, new residuals are transformed using self.transformer_y.
             
         Returns 
         -------
         self
-        '''
+
+        """
 
         if not isinstance(residuals, pd.Series):
             raise Exception(
                 f"`residuals` argument must be `pd.Series`. Got {type(residuals)}"
             )
+
+        if not transform and self.transformer_y is not None:
+            warnings.warn(
+                f'''
+                Argument `transform` is set to `False` but forecaster was trained
+                using a transformer {self.transformer_y}. Ensure that new residuals 
+                are already transformed or set `transform=True`.
+                '''
+            )
+
+        if transform and self.transformer_y is not None:
+            warnings.warn(
+                f'''
+                Residuals will be transformed using the same transformer used 
+                when training the forecaster ({self.transformer_y}). Ensure that
+                new residuals are in the same scale as the original time series.
+                '''
+            )
+
+            residuals = transform_series(
+                            series            = residuals,
+                            transformer       = self.transformer_y,
+                            fit               = False,
+                            inverse_transform = False
+                        )
             
         if len(residuals) > 1000:
             rng = np.random.default_rng(seed=123)
@@ -823,53 +991,12 @@ class ForecasterAutoregCustom(ForecasterBase):
                             ))
 
         self.out_sample_residuals = pd.Series(residuals)
-                
-
-    def get_coef(self) -> pd.DataFrame:
-        '''      
-        Return estimated coefficients for the regressor stored in the forecaster.
-        Only valid when regressor stores internally the feature coefficients in
-        the attribute `coef_`.
-        
-        Parameters
-        ----------
-        self
-
-        Returns 
-        -------
-        coef : pandas DataFrame
-            Value of the coefficients associated with each predictor.
-        
-        '''
-        warnings.warn(
-            f'This method was deprecated in version 0.4.3 in favor of the get_feature_importance. '
-            f'This method will be removed in 0.4.4', DeprecationWarning
-        )
-        
-        if isinstance(self.regressor, sklearn.pipeline.Pipeline):
-            estimator = self.regressor[-1]
-        else:
-            estimator = self.regressor
-
-        try:
-            coef = pd.DataFrame({
-                        'feature': self.X_train_col_names,
-                        'coef' : estimator.coef_
-                   })
-        except:
-            warnings.warn(
-                f"Impossible to access feature coefficients for regressor of type {type(estimator)}. "
-                f"This method is only valid when the regressor stores internally "
-                f" the coefficients in the attribute `coef_`."
-            )
-
-            coef = None
-            
-        return coef
 
     
-    def get_feature_importance(self) -> pd.DataFrame:
-        '''      
+    def get_feature_importance(
+        self
+    ) -> pd.DataFrame:
+        """      
         Return feature importance of the regressor stored in the
         forecaster. Only valid when regressor stores internally the feature
         importance in the attribute `feature_importances_` or `coef_`.
@@ -882,7 +1009,14 @@ class ForecasterAutoregCustom(ForecasterBase):
         -------
         feature_importance : pandas DataFrame
             Feature importance associated with each predictor.
-        '''
+
+        """
+
+        if self.fitted == False:
+            raise sklearn.exceptions.NotFittedError(
+                "This forecaster is not fitted yet. Call `fit` with appropriate "
+                "arguments before using `get_feature_importance()`."
+            )
 
         if isinstance(self.regressor, sklearn.pipeline.Pipeline):
             estimator = self.regressor[-1]
@@ -910,4 +1044,4 @@ class ForecasterAutoregCustom(ForecasterBase):
 
                 feature_importance = None
 
-        return feature_importance
+        return feature_importance
\ No newline at end of file
